@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: clientsession
 version: 0.9.1.1
-id: clientsession-0.9.1.1-763bfd866302839ae7dcaa53517a3160
-key: clien_LuobzRZeZj55iOint27HgG
+id: clientsession-0.9.1.1-b8e6f456b3509830746dc1bc910c0131
+key: clien_9IM29FMu1faCDg0EecHqUM
 license: BSD3
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: stable
@@ -23,16 +23,16 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/clientsession-0.9.1.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/clientsession-0.9.1.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/clientsession-0.9.1.1
-hs-libraries: HSclientsession-0.9.1.1-LuobzRZeZj55iOint27HgG
+hs-libraries: HSclientsession-0.9.1.1-9IM29FMu1faCDg0EecHqUM
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     cereal-0.5.1.0-2c7be146776a4abf674d1ac9e0ccfc13
-    cipher-aes-0.2.11-25252cf5003ba05bef45f1bdfd72c181
-    cprng-aes-0.6.1-4f88e976d4e99640259c02d6940382c2
+    cipher-aes-0.2.11-78f8e669d2c7fa2c876e85f22e882b22
+    cprng-aes-0.6.1-31f334ac9b899d0af12f1cbac49d2287
     crypto-api-0.13.2-095d0cf567bb83558b8b8ae881dd04fd
-    crypto-random-0.0.9-1a34631cfa2fcb67c67a6201143b0147
+    crypto-random-0.0.9-bdb6a693941c8915b178724d04100946
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     entropy-0.3.7-db9feabff8921cc1dd6e8db21278a74f
     setenv-0.1.1.3-4d70f2e61b1bd0645017164a0ca26ee9
